@@ -12,7 +12,7 @@ impl nutmeg::Model for Model {
 }
 
 fn main() {
-    let mut view = nutmeg::View::new(Model {}, nutmeg::ViewOptions::default());
+    let mut view = nutmeg::View::new(Model {}, nutmeg::Options::default());
     for i in 1..=5 {
         writeln!(view, "write line {}", i).unwrap();
     }
